%global momorel 2

Summary: Bluetooth utilities
Name: bluez
Version: 4.69
Release: %{momorel}m%{?dist}
License: GPLv2+
Group: Applications/System
Source: http://www.kernel.org/pub/linux/bluetooth/%{name}-%{version}.tar.bz2
NoSource: 0
Source1: bluetooth.init
Source3: dund.init
Source4: dund.conf
Source5: pand.init
Source6: pand.conf
Source7: rfcomm.init
Source8: bluez-uinput.modules

Patch1: bluez-utils-oui-usage.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=450081
# http://thread.gmane.org/gmane.linux.bluez.kernel/1687
Patch2: bluez-try-utf8-harder.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=498756
Patch4: bluez-socket-mobile-cf-connection-kit.patch
# http://thread.gmane.org/gmane.linux.bluez.kernel/2396
Patch5: 0001-Add-sixaxis-cable-pairing-plugin.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
URL: http://www.bluez.org/
BuildRequires: glib-devel >= 1.2

BuildRequires: flex
BuildRequires: dbus-devel >= 0.90
BuildRequires: libusb-devel, glib2-devel, alsa-lib-devel
BuildRequires: gstreamer-plugins-base-devel, gstreamer-devel
BuildRequires: libsndfile-devel
BuildRequires: libcap-ng-devel
# For cable pairing
BuildRequires: libudev-devel 
%ifnarch s390 s390x
BuildRequires: libusb1-devel
%endif
BuildRequires: udev

# For rebuild
BuildRequires: autoconf automake libtool

Obsoletes: bluez-pan < 4.0, bluez-sdp < 4.0
Requires: initscripts, bluez-libs = %{version}
Requires: dbus >= 0.60
Requires: hwdata >= 0.215
# Requires: dbus-bluez-pin-helper
Requires: udev >= 147
Requires(preun): chkconfig, initscripts
Requires(post): chkconfig, initscripts

Obsoletes: bluez-utils < 4.5
Provides: bluez-utils = %{version}-%{release}


%description
Utilities for use in Bluetooth applications:
	- hcitool
	- hciattach
	- hciconfig
	- bluetoothd
	- l2ping
	- start scripts
	- pcmcia configuration files

The BLUETOOTH trademarks are owned by Bluetooth SIG, Inc., U.S.A.

%package libs
Summary: Libraries for use in Bluetooth applications
Group: System Environment/Libraries

%package libs-devel
Summary: Development libraries for Bluetooth applications
Group: Development/Libraries
Requires: bluez-libs = %{version}
Requires: pkgconfig
Obsoletes: bluez-sdp-devel < 4.0

%package cups
Summary: CUPS printer backend for Bluetooth printers
Group: System Environment/Daemons
Obsoletes: bluez-utils-cups < 4.5-2
Provides: bluez-utils-cups = %{version}-%{release}
Requires: bluez-libs = %{version}
Requires: cups

%package gstreamer
Summary: GStreamer support for SBC audio format
Group: System Environment/Daemons
Obsoletes: bluez-utils-gstreamer < 4.5-2
Provides: bluez-utils-gstreamer = %{version}-%{release}
Requires: bluez-libs = %{version}

%package alsa
Summary: ALSA support for Bluetooth audio devices
Obsoletes: bluez-utils-alsa < 4.5-2
Provides: bluez-utils-alsa = %{version}-%{release}
Group: System Environment/Daemons
Requires: bluez-libs = %{version}

%package compat
Summary: Compatibility utilities for Bluetooth devices
Group: System Environment/Daemons
Requires: bluez-libs = %{version}

%description cups
This package contains the CUPS backend

%description gstreamer
This package contains gstreamer plugins for the Bluetooth SBC audio format

%description alsa
This package contains ALSA support for Bluetooth audio devices

%description libs
Libraries for use in Bluetooth applications.

%description libs-devel
bluez-libs-devel contains development libraries and headers for
use in Bluetooth applications.

%description compat
This package contains compatibility utilities for Bluetooth devices.
This includes hidd, dund and pand.

%prep

%setup -q

%patch1 -p0 -b .oui
%patch2 -p1 -b .non-utf8-name
%patch4 -p1 -b .socket-mobile
%patch5 -p1 -b .cable-pairing

libtoolize -c -f
autoreconf

%build
%configure --enable-cups --enable-dfutool --enable-tools --enable-bccmd --enable-gstreamer --enable-hidd --enable-pand --enable-dund

make

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
/sbin/ldconfig -n %{buildroot}/%{_libdir}
# Remove autocrap and libtool droppings
rm -f %{buildroot}/%{_libdir}/*.la				\
	%{buildroot}/%{_libdir}/alsa-lib/*.la		\
	%{buildroot}/%{_libdir}/bluetooth/plugins/*.la	\
	%{buildroot}/%{_libdir}/gstreamer-0.10/*.la

for a in bluetooth dund pand rfcomm ; do 
	install -D -m 755 %{_sourcedir}/$a.init %{buildroot}%{_initscriptdir}/$a
	if [ -e %{_sourcedir}/$a.conf ] ; then
		install -D -m 644 %{_sourcedir}/$a.conf %{buildroot}%{_sysconfdir}/sysconfig/$a
	fi
done

# Remove the cups backend from libdir, and install it in /usr/lib whatever the install
if test -d %{buildroot}/usr/lib64/cups ; then
	install -D -m 755 %{buildroot}/usr/lib64/cups/backend/bluetooth %{buildroot}/usr/lib/cups/backend/bluetooth
	rm -rf %{buildroot}%{_libdir}/cups
fi

rm -f %{buildroot}%{_sysconfdir}/udev/*.rules %{buildroot}lib/udev/rules.d/*.rules
install -D -m 644 scripts/bluetooth-serial.rules %{buildroot}%{_sysconfdir}/udev/rules.d/97-bluetooth-serial.rules
 install -D -m 755 scripts/bluetooth_serial %{buildroot}/lib/udev/bluetooth_serial
install -D -m 644 scripts/97-bluetooth.rules %{buildroot}/lib/udev/rules.d/97-bluetooth.rules
install -D -m 755 scripts/bluetooth_serial %{buildroot}/lib/udev/bluetooth_serial

install -D -m 755 %{SOURCE8} %{buildroot}%{_sysconfdir}/sysconfig/modules/bluez-uinput.modules

install -d -m 755 %{buildroot}%{_localstatedir}/lib/bluetooth

%clean
rm -rf %{buildroot}

%post libs -p /sbin/ldconfig

%post
/sbin/chkconfig --add bluetooth
if [ "$1" -ge "1" ]; then
	/sbin/service bluetooth condrestart >/dev/null 2>&1 || :
fi
exit 0

%postun libs -p /sbin/ldconfig

%preun
if [ "$1" = "0" ]; then
	/sbin/service bluetooth stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del bluetooth
fi

%post compat
/sbin/chkconfig --add dund
/sbin/chkconfig --add pand
/sbin/chkconfig --add rfcomm
if [ "$1" -ge "1" ]; then
	/sbin/service dund condrestart >/dev/null 2>&1 || :
	/sbin/service pand condrestart >/dev/null 2>&1 || :
	/sbin/service rfcomm condrestart >/dev/null 2>&1 || :
fi
exit 0

%preun compat
if [ "$1" = "0" ]; then
	/sbin/service dund stop >/dev/null 2>&1 || :
	/sbin/service pand stop >/dev/null 2>&1 || :
	/sbin/service rfcomm stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del dund
	/sbin/chkconfig --del pand
	/sbin/chkconfig --del rfcomm
fi

%files
%defattr(-, root, root)
%{_bindir}/ciptool
%{_bindir}/dfutool
%{_bindir}/hcitool
%{_bindir}/l2ping
%{_bindir}/rfcomm
%{_bindir}/sdptool
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%dir %{_sysconfdir}/bluetooth
%config(noreplace) %{_sysconfdir}/bluetooth/main.conf
%config(noreplace) %{_sysconfdir}/sysconfig/modules/bluez-uinput.modules
%config %{_sysconfdir}/dbus-1/system.d/bluetooth.conf
%{_libdir}/bluetooth
/lib/udev/bluetooth_serial
/lib/udev/rules.d/97-bluetooth.rules
%{_sysconfdir}/udev/rules.d/97-bluetooth-serial.rules
%{_initscriptdir}/bluetooth
%{_localstatedir}/lib/bluetooth

%files libs
%defattr(-, root, root)
%doc AUTHORS COPYING* ChangeLog INSTALL README
%{_libdir}/libbluetooth.so.*

%files libs-devel
%defattr(-, root, root)
%{_includedir}/bluetooth
%{_libdir}/libbluetooth.so
%{_libdir}/pkgconfig/bluez.pc

%files cups
%defattr(-, root, root)
/usr/lib/cups/backend/bluetooth

%files gstreamer
%defattr(-, root, root)
%{_libdir}/gstreamer-*/*.so

%files alsa
%defattr(-, root, root)
%{_libdir}/alsa-lib/*.so
%{_sysconfdir}/alsa/bluetooth.conf

%files compat
%defattr(-, root, root)
%{_bindir}/dund
%{_bindir}/pand
%{_bindir}/hidd
%config(noreplace) %{_sysconfdir}/bluetooth/rfcomm.conf
%{_initscriptdir}/dund
%{_initscriptdir}/rfcomm
%{_initscriptdir}/pand
%config(noreplace) %{_sysconfdir}/sysconfig/dund
%config(noreplace) %{_sysconfdir}/sysconfig/pand

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (4.69-2m)
- full rebuild for mo7 release

* Thu Jul 29 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (4.69-1m)
- update to 4.69

* Sat May  1 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.64-1m)
- update to 4.64

* Sun Dec 27 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (4.59-1m)
- version 4.59

* Sat Dec 12 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (4.58-1m)
- version 4.58
- remove --enable-hid2hci from %%configure, move hid2hci to udev

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.36-3m)
- rebuild against gcc-4.4 and glibc-2.11

* Sat Sep 26 2009 Nishio Futoshi <futoshi@momonga-linux.org>
- (4.36-2m)
- comment out Requires: dbus-bluez-pin-helper

* Sat Apr 18 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.36-1m)
- update 4.36

* Fri Apr  3 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.34-1m)
- update 4.34

* Mon Mar  2 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.32-1m)
- update 4.32

* Sun Feb 22 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.30-1m)
- update 4.30

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (4.27-2m)
- rebuild against rpm-4.6

* Tue Jan 20 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.27-1m)
- update 4.27

* Fri Jan  2 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (4.25-2m)
- fix %%files
- %%{_sysconfdir}/sysconfig/modules is a directory provided by initscripts not a file
- do not glob by %%config(noreplace)

* Thu Jan  1 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.25-1m)
- update 4.25

* Mon Dec 22 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.23-1m)
- update 4.23

* Wed Dec 17 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (4.22-1m)
- rename bluez. bluez was merged bluez-libs and bluez-utils
- update 4.22

* Tue Jul 15 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (3.36-1m)
- [SECURITY] CVE-2008-2374
- update to 3.36

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.26-2m)
- rebuild against gcc43

* Sat Feb 23 2007 Yohsuke Ooi <ichiro@n.email.ne.jp>
- (3.26-1m)
- update 3.26

* Thu Feb 15 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.9-2m)
- Obsoletes: bluez-pin

* Thu Feb 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (3.9-1m)
- update 3.9

* Tue May  2 2006 Masaru SANUKI <sanuki@momonga-linux.org>
- (2.21-2m)
- rebuild against dbus-0.61

* Sun Oct 30 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.21-1m)
- version 2.21
- rebuild against dbus-0.50
- remove Patch0, Patch1 --- contents taken into source

* Mon Feb 28 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (2.14-1m)
- import from FC

* Thu Jan 20 2005 David Woodhouse <dwmw2@redhat.com> 2.14-2
- Update to bluez-libs 2.14
- Restore hci_remote_name() and hci_local_name() functions

* Wed Jan 12 2005 David Woodhouse <dwmw2@redhat.com> 2.13-1
- Update to bluez-libs 2.13

* Mon Aug 16 2004 David Woodhouse <dwmw2@redhat.com> 2.10-2
- Switch to nicer unaligned access macros

* Sat Aug 14 2004 David Woodhouse <dwmw2@redhat.com> 2.10-1
- Update to bluez-libs 2.10

* Tue Aug 03 2004 David Woodhouse <dwmw2@redhat.com> 2.9-1
- Update to bluez-libs 2.9

* Tue Jul 20 2004 David Woodhouse <dwmw2@redhat.com> 2.8-1
- Update to bluez-libs 2.8

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue May 11 2004 David Woodhouse <dwmw2@redhat.com> 2.7-1
- Update to bluez-libs 2.7

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Feb 10 2004 Karsten Hopp <karsten@redhat.de> 2.5-1 
- update to 2.5

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Apr 24 2003 David Woodhouse <dwmw2@redhat.com>
- update to bluez-libs 2.4.

* Tue Feb 04 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- add symlinks to shared libs

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Thu Jan 16 2003 Bill Nottingham <notting@redhat.com> 2.3-1
- initial build
